==> aliyun-java-sdk-ecs-2.2.0-sources.jar: com/aliyuncs/ecs/transform/v20140526/EipFillProductResponseUnmarshaller.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.aliyuncs.ecs.transform.v20140526;

import com.aliyuncs.ecs.model.v20140526.EipFillProductResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class EipFillProductResponseUnmarshaller {

	public static EipFillProductResponse unmarshall(EipFillProductResponse eipFillProductResponse, UnmarshallerContext context) {
		
		eipFillProductResponse.setrequestId(context.stringValue("EipFillProductResponse.requestId"));
		eipFillProductResponse.setdata(context.stringValue("EipFillProductResponse.data"));
		eipFillProductResponse.setcode(context.stringValue("EipFillProductResponse.code"));
		eipFillProductResponse.setsuccess(context.booleanValue("EipFillProductResponse.success"));
		eipFillProductResponse.setmessage(context.stringValue("EipFillProductResponse.message"));
	 
	 	return eipFillProductResponse;
	}
}

==> aliyun-java-sdk-ecs-4.2.0-sources.jar: com/aliyuncs/ecs/transform/v20140526/EipFillProductResponseUnmarshaller.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.aliyuncs.ecs.transform.v20140526;

import com.aliyuncs.ecs.model.v20140526.EipFillProductResponse;
import com.aliyuncs.transform.UnmarshallerContext;


public class EipFillProductResponseUnmarshaller {

	public static EipFillProductResponse unmarshall(EipFillProductResponse eipFillProductResponse, UnmarshallerContext context) {
		
		eipFillProductResponse.setRequestId(context.stringValue("EipFillProductResponse.requestId"));
		eipFillProductResponse.setData(context.stringValue("EipFillProductResponse.data"));
		eipFillProductResponse.setCode(context.stringValue("EipFillProductResponse.code"));
		eipFillProductResponse.setSuccess(context.booleanValue("EipFillProductResponse.success"));
		eipFillProductResponse.setMessage(context.stringValue("EipFillProductResponse.message"));
	 
	 	return eipFillProductResponse;
	}
}
